@@ -117,7 +117,7 @@ int CgidWorker::start(const char *pServerRoot, const char *pChroot,
         chmod(p + 5, 0760);
     }
     else
-        chmod(p + 5, 0700);
+        ;//chmod(p + 5, 0700);
 
     if (pChroot)
     {
@@ -151,6 +151,7 @@ int CgidWorker::spawnCgid(int fd, char *pData, const char *secret)
 {
     int pid;
     const char *pChroot = "";
+
     if (ServerProcessConfig::getInstance().getChroot() != NULL)
         pChroot = ServerProcessConfig::getInstance().getChroot()->c_str();
     snprintf(pData, 255, "uds:/%s%s", pChroot,
