@@ -1,6 +1,6 @@
 /*****************************************************************************
 *    Open LiteSpeed is an open source HTTP server.                           *
-*    Copyright (C) 2013 - 2018  LiteSpeed Technologies, Inc.                 *
+*    Copyright (C) 2013 - 2020  LiteSpeed Technologies, Inc.                 *
 *                                                                            *
 *    This program is free software: you can redistribute it and/or modify    *
 *    it under the terms of the GNU General Public License as published by    *
@@ -25,13 +25,12 @@
 #include <sys/types.h>
 #include <sys/uio.h>
 
-
 ChunkInputStream::ChunkInputStream()
-    : m_pIS(NULL)
-    , m_iChunkLen(INIT_CHUNK_LEN)
-    , m_iRemain(0)
 {
+    LS_ZERO_FILL(m_pIS, m_iBufUsed);
 }
+
+
 ChunkInputStream::~ChunkInputStream()
 {
 }
