@@ -1,6 +1,6 @@
 /*****************************************************************************
 *    Open LiteSpeed is an open source HTTP server.                           *
-*    Copyright (C) 2013 - 2018  LiteSpeed Technologies, Inc.                 *
+*    Copyright (C) 2013 - 2020  LiteSpeed Technologies, Inc.                 *
 *                                                                            *
 *    This program is free software: you can redistribute it and/or modify    *
 *    it under the terms of the GNU General Public License as published by    *
@@ -63,6 +63,8 @@ HttpServerConfig::HttpServerConfig()
     , m_iChildren(1)
     , m_pAdminSock(NULL)
     , m_pGlobalVHost(NULL)
+    , m_bwrap(BWRAP_DISABLED)
+    , m_pBwrapCmdLine(NULL)
 {
     m_pDeniedDir = new DeniedDir();
 }
