@@ -1,6 +1,6 @@
 /*****************************************************************************
 *    Open LiteSpeed is an open source HTTP server.                           *
-*    Copyright (C) 2013 - 2020  LiteSpeed Technologies, Inc.                 *
+*    Copyright (C) 2013 - 2018  LiteSpeed Technologies, Inc.                 *
 *                                                                            *
 *    This program is free software: you can redistribute it and/or modify    *
 *    it under the terms of the GNU General Public License as published by    *
@@ -26,6 +26,7 @@
 
 #include <errno.h>
 #include <fcntl.h>
+#include <signal.h>
 #include <stdio.h>
 #include <string.h>
 #include <sys/stat.h>
@@ -71,7 +72,7 @@ int DirHashCacheStore::isEntryExist(const CacheHash &hash, const char *pSuffix,
 {
     char achBuf[4096];
     struct stat st;
-    int n = buildCacheLocation(achBuf, 4096, hash, isPrivate);
+    int n = buildCacheLocation(achBuf, 4096, hash.getKey(), isPrivate);
     if (pSuffix)
         lstrncpy(&achBuf[n], pSuffix, sizeof(achBuf) - n);
     if (!pStat)
@@ -118,7 +119,7 @@ int DirHashCacheStore::processStale(CacheEntry *pEntry, char *pBuf,
         {
             pEntry->setStale(1);
             if (!pathLen)
-                pathLen = buildCacheLocation(pBuf, 4096, pEntry->getHashKey(),
+                pathLen = buildCacheLocation(pBuf, 4096, pEntry->getHashKey().getKey(),
                                              pEntry->isPrivate());
             if (renameDiskEntry(pEntry, pBuf, maxBuf, NULL, ".S",
                                 DHCS_SOURCE_MATCH | DHCS_DEST_CHECK) != 0)
@@ -158,7 +159,7 @@ CacheEntry *DirHashCacheStore::getCacheEntry(CacheHash &hash,
 
         debug_dump(pEntry, "found entry in hash");
 
-        if (pEntry->isUnderConstruct())
+        if (pEntry->isBuilding())
             return pEntry;
 
         int lastCheck = ((DirHashCacheEntry *)pEntry)->m_lastCheck;
@@ -166,7 +167,7 @@ CacheEntry *DirHashCacheStore::getCacheEntry(CacheHash &hash,
         if ((DateTime::s_curTime != lastCheck)
             || (lastCheck == -1))   //This entry is being written to disk
         {
-            pathLen = buildCacheLocation(achBuf, 4096, hash,
+            pathLen = buildCacheLocation(achBuf, 4096, hash.getKey(),
                                          pEntry->isPrivate());
             if (isChanged((DirHashCacheEntry *)pEntry, achBuf, pathLen, sizeof(achBuf)))
             {
@@ -181,10 +182,17 @@ CacheEntry *DirHashCacheStore::getCacheEntry(CacheHash &hash,
             }
         }
     }
+    else
+    {
+        if (!getManager()->isInTracker(hash.getKey(), HASH_KEY_LEN, 
+                                       pKey->m_pIP != NULL))
+            return NULL;
+    }
+    
     if ((pEntry == NULL) || (pEntry->getFdStore() == -1))
     {
         if (!pathLen)
-            pathLen = buildCacheLocation(achBuf, 4096, hash,
+            pathLen = buildCacheLocation(achBuf, 4096, hash.getKey(),
                                          pKey->m_pIP != NULL);
 
         fd = ::open(achBuf, O_RDONLY);
@@ -222,11 +230,33 @@ CacheEntry *DirHashCacheStore::getCacheEntry(CacheHash &hash,
         pEntry->setFdStore(fd);
         pEntry->setHashKey(hash);
         //pEntry->setKey( hash, pURI, iURILen, pQS, iQSLen, pIP, ipLen, pCookie, cookieLen );
-        pEntry->loadCeHeader();
+        if (pEntry->loadCeHeader() == -1)
+        {
+            delete pEntry;
+            return NULL;
+        };
         //assert( pEntry->verifyHashKey() == 0 );
 
         debug_dump(pEntry, "load entry from disk");
 
+        if (pEntry->isUnderConstruct())
+        {
+            if (isCreatorAlive(pEntry))
+            {
+                g_api->log(NULL, LSI_LOG_INFO, 
+                           "[CACHE] %p [%s], is under construction by PID: %d",
+                            pEntry, pEntry->getHashKey().to_str(NULL),
+                            pEntry->getHeader().m_pidCreator);
+                addToHash(pEntry);
+            }
+            else
+            {
+                removeDeadEntry(pEntry, hash, achBuf);
+                pEntry = NULL;
+            }    
+            return pEntry;
+        }
+        
         updateEntryState((DirHashCacheEntry *)pEntry);
         if (stale)
         {
@@ -246,13 +276,16 @@ CacheEntry *DirHashCacheStore::getCacheEntry(CacheHash &hash,
                "[CACHE] check [%p] against cache manager, tag: '%s' \n",
                pEntry, pEntry->getTag().c_str());
 
-    if (pEntry->getHeader().m_tmCreated <= lastCacheFlush)
+    if ( !dispose && pEntry->getHeader().m_tmCreated <= lastCacheFlush)
     {
         g_api->log(NULL, LSI_LOG_DEBUG,
                    "[CACHE] [%p] has been flushed, dispose.\n", pEntry);
         dispose = 1;
     }
-
+    g_api->log(NULL, LSI_LOG_DEBUG,
+               "[CACHE] check [%p] against cache manager, tag: '%s' \n",
+               pEntry, pEntry->getTag().c_str());
+    
     if (!dispose )
     {
         int flag = getManager()->isPurged(pEntry, pKey, (lastCacheFlush >= 0));
@@ -274,10 +307,13 @@ CacheEntry *DirHashCacheStore::getCacheEntry(CacheHash &hash,
             CacheStore::dispose(iter, 1);
         else
         {
-            if (!achBuf[0])
-                buildCacheLocation(achBuf, 4096, hash, pEntry->isPrivate());
-            delete pEntry;
-            unlink(achBuf);
+            if (pEntry->isStale())
+            {
+                if (!achBuf[0])
+                    buildCacheLocation(achBuf, 4096, hash.getKey(), pEntry->isPrivate());
+                strcpy(&achBuf[pathLen], ".S");
+            }
+            removeDeadEntry(pEntry, hash, achBuf);
         }
         return NULL;
     }
@@ -296,19 +332,26 @@ CacheEntry *DirHashCacheStore::getCacheEntry(CacheHash &hash,
         return NULL;
     }
     if (iter == end())
-        insert((char *)pEntry->getHashKey().getKey(), pEntry);
+        addToHash(pEntry);
     return pEntry;
 
 }
 
-int DirHashCacheStore::buildCacheLocation(char *pBuf, int len,
-        const CacheHash &hash, int isPrivate)
+
+int DirHashCacheStore::isCreatorAlive(CacheEntry *pEntry)
 {
-    const unsigned char *achHash = hash.getKey();
-    int n = snprintf(pBuf, len, "%s%s%x/%x/%x/", getRoot().c_str(),
-                     isPrivate ? "priv/" : "",
-                     (achHash[0]) >> 4, achHash[0] & 0xf, (achHash[1]) >> 4);
-    StringTool::hexEncode((char *)achHash, HASH_KEY_LEN, &pBuf[n]);
+    if (pEntry->getHeader().m_pidCreator == 0)
+        return 0;
+    return (kill(pEntry->getHeader().m_pidCreator, 0) != -1 
+            || errno != ESRCH);
+}
+
+
+int DirHashCacheStore::buildCacheLocation(char *pBuf, int len,
+        const unsigned char *pHashKey, int isPrivate)
+{
+    int n = getCacheDirPath(pBuf, len, pHashKey, isPrivate);
+    StringTool::hexEncode((char *)pHashKey, HASH_KEY_LEN, &pBuf[n]);
     n += 2 * HASH_KEY_LEN;
     return n;
 }
@@ -362,32 +405,24 @@ static int createMissingPath(char *pPath, char *pPathEnd, int isPrivate)
 
 }
 
-CacheEntry *DirHashCacheStore::createCacheEntry(
-    const CacheHash &hash, CacheKey *pKey, int force)
+
+
+int DirHashCacheStore::createCacheFile(const CacheHash *pHash, bool is_private)
 {
     char achBuf[4096];
     char *pPathEnd;
-    int n = buildCacheLocation(achBuf, 4096, hash, pKey->m_pIP != NULL);
+    int n = buildCacheLocation(achBuf, 4096, pHash->getKey(), is_private);
     struct stat st;
     TempUmask tumsk(0007);
 
-//    if ( stat( achBuf, &st ) == 0 )
-//    {
-//        if ( !force )
-//            return NULL;
-//        //FIXME: rename the cache entry to make it dirty
-//    }
-//    else
+    lstrncpy(&achBuf[n], ".tmp", sizeof(achBuf) - n);
+    if (nio_stat(achBuf, &st) == 0)
     {
-        lstrncpy(&achBuf[n], ".tmp", sizeof(achBuf) - n);
-        if (nio_stat(achBuf, &st) == 0)
-        {
-            //in progress
-            if (DateTime::s_curTime - st.st_mtime > 120)
-                unlink(achBuf);
-            else
-                return NULL;
-        }
+        //in progress
+        if (DateTime::s_curTime - st.st_mtime > 120)
+            unlink(achBuf);
+        else
+            return -1;
     }
 
     pPathEnd = &achBuf[n - 2 * HASH_KEY_LEN - 1];
@@ -395,34 +430,59 @@ CacheEntry *DirHashCacheStore::createCacheEntry(
 
     if ((nio_stat(achBuf, &st) == -1) && (errno == ENOENT))
     {
-        if (createMissingPath(achBuf, pPathEnd,
-                              pKey->isPrivate()) == -1)
-            return NULL;
+        if (createMissingPath(achBuf, pPathEnd, is_private) == -1)
+            return -1;
 
     }
     *pPathEnd = '/';
 
     int fd = ::open(achBuf, O_RDWR | O_CREAT | O_TRUNC | O_EXCL, 0660);
+    if (fd != -1)
+        ::fcntl(fd, F_SETFD, FD_CLOEXEC);
+    //LS_INFO( "createCacheEntry(), open fd: %d", fd ));
+    return fd;
+}
+
+
+CacheEntry *DirHashCacheStore::createCacheEntry(
+    const CacheHash &hash, CacheKey *pKey)
+{
+    bool is_private = pKey->isPrivate();
+    int fd = createCacheFile(&hash, is_private);
     if (fd == -1)
         return NULL;
-    ::fcntl(fd, F_SETFD, FD_CLOEXEC);
-    //LS_INFO( "createCacheEntry(), open fd: %d", fd ));
 
     CacheEntry *pEntry = new DirHashCacheEntry();
     pEntry->setFdStore(fd);
     pEntry->setKey(hash, pKey);
-    if (pKey->m_pIP && pKey->m_ipLen > 0)
+    return initCacheEntry(pEntry, is_private);
+}
+
+
+
+CacheEntry *DirHashCacheStore::initCacheEntry(CacheEntry *pEntry, bool is_private)
+{
+    static pid_t s_pid = 0;
+    pEntry->setBuilding(1);
+    if (is_private)
         pEntry->getHeader().m_flag |= CeHeader::CEH_PRIVATE;
-    //Do not save now since tag is not ready, will call it later
-    //pEntry->saveCeHeader();
+    int32_t lastmode = pEntry->getHeader().m_tmLastMod;
+    if (s_pid == 0)
+        s_pid = getpid();
+    pEntry->getHeader().m_pidCreator = s_pid;
+    pEntry->saveCeHeader();
+    pEntry->getHeader().m_tmLastMod = lastmode;
 
     //update current entry
-    CacheStore::iterator iter = find(hash.getKey());
+    CacheStore::iterator iter = find(pEntry->getHashKey().getKey());
     if (iter != end())
         iter.second()->setUpdating(1);
+    else
+        addToHash(pEntry);
     return pEntry;
 }
 
+
 // remove:  0  do not remove temp file
 //          1  remove temp file without checking
 //          -1 check temp file inode then remove
@@ -434,7 +494,7 @@ void DirHashCacheStore::cancelEntry(CacheEntry *pEntry, int remove)
         iter.second()->setUpdating(0);
     if (remove)
     {
-        int n = buildCacheLocation(achBuf, 4096, pEntry->getHashKey(),
+        int n = buildCacheLocation(achBuf, 4096, pEntry->getHashKey().getKey(),
                                    pEntry->isPrivate());
         lstrncpy(&achBuf[n], ".tmp", sizeof(achBuf) - n);
         if ((pEntry->getFdStore() != -1) && remove == -1)
@@ -451,11 +511,40 @@ void DirHashCacheStore::cancelEntry(CacheEntry *pEntry, int remove)
     }
     close(pEntry->getFdStore());
     pEntry->setFdStore(-1);
-    delete pEntry;
+    cancelEntryInMem(pEntry);
 
 }
 
 
+void DirHashCacheStore::cancelEntryInMem(CacheEntry* pEntry)
+{
+    if (pEntry->getFdStore() != -1)
+    {
+        close(pEntry->getFdStore());
+        pEntry->setFdStore(-1);
+    }
+
+    CacheStore::iterator iter = find(pEntry->getHashKey().getKey());
+    if (iter != end())
+    {
+        if (iter.second() != pEntry)
+            iter.second()->setUpdating(0);
+        else
+        {
+            getManager()->removeTracking((const char *)(pEntry->getHashKey().getKey()),
+                                        HASH_KEY_LEN, pEntry->isPrivate());
+            erase(iter);
+        }
+    }
+    if (pEntry->getRef() > 0)
+    {
+        addToDirtyList(pEntry);
+    }
+    else
+        delete pEntry;
+
+}
+
 CacheEntry *DirHashCacheStore::getCacheEntry(const char *pKey,
         int keyLen)
 {
@@ -477,7 +566,7 @@ int DirHashCacheStore::saveEntry(CacheEntry *pEntry)
 void DirHashCacheStore::removePermEntry(CacheEntry *pEntry)
 {
     char achBuf[4096];
-    buildCacheLocation(achBuf, 4096, pEntry->getHashKey(),
+    buildCacheLocation(achBuf, 4096, pEntry->getHashKey().getKey(),
                        pEntry->isPrivate());
     unlink(achBuf);
 }
@@ -485,7 +574,7 @@ void DirHashCacheStore::removePermEntry(CacheEntry *pEntry)
 void DirHashCacheStore::getEntryFilePath(CacheEntry *pEntry, char *pPath, int &len)
 {
     assert(len >= 4096);
-    len = buildCacheLocation(pPath, 4096, pEntry->getHashKey(),
+    len = buildCacheLocation(pPath, 4096, pEntry->getHashKey().getKey(),
                              pEntry->isPrivate());
 }
 /*
@@ -552,7 +641,7 @@ int DirHashCacheStore::renameDiskEntry(CacheEntry *pEntry, char *pFrom,
         pFrom = achFrom;
         maxFrom = sizeof(achFrom);
     }
-    int n = buildCacheLocation(pFrom, 4090, pEntry->getHashKey(),
+    int n = buildCacheLocation(pFrom, 4090, pEntry->getHashKey().getKey(),
                                pEntry->isPrivate());
     if (n == -1)
         return -1;
@@ -586,6 +675,51 @@ int DirHashCacheStore::renameDiskEntry(CacheEntry *pEntry, char *pFrom,
 
 }
 
+
+int DirHashCacheStore::updateEntryExpire(CacheEntry* pEntry)
+{
+    int fd = pEntry->getFdStore();
+    if (fd == -1)
+    {
+        errno = EBADF;
+        return -1;
+    }
+    
+    pEntry->getHeader().m_tmExpire += DateTime::s_curTime -
+                                      pEntry->getHeader().m_tmCreated;
+    off_t curOffset = lseek(fd, 0, SEEK_CUR);
+
+    if (nio_lseek(fd, pEntry->getStartOffset() + CACHE_ENTRY_MAGIC_LEN,
+                  SEEK_SET) == -1)
+        return -1;
+    if (nio_write(fd, &pEntry->getHeader(), sizeof(CeHeader)) <
+        (int)sizeof(CeHeader))
+        return -1;
+
+    lseek(fd, curOffset, SEEK_SET);
+    return 0;
+}
+
+
+int DirHashCacheStore::updateHashEntry(CacheEntry* pEntry)
+{
+    updateEntryState((DirHashCacheEntry *)pEntry);
+    pEntry->setLastPurgrCheck(DateTime::s_curTime);
+    CacheStore::iterator iter = find(pEntry->getHashKey().getKey());
+    getManager()->incStats(pEntry->isPrivate(), offsetof(cachestats_t,
+                           created));
+    if (iter != end())
+    {
+        if (iter.second() == pEntry)
+            return 0;
+        dispose(iter, 0);
+    }
+    addToHash(pEntry);
+//     if (!pEntry->isPrivate() && pEntry->isEsi())
+//         getManager()->getCacheInfo()->addLitemageCached(1);
+    return 0;
+}
+
 int DirHashCacheStore::publish(CacheEntry *pEntry)
 {
     char achTmp[4096];
@@ -603,6 +737,9 @@ int DirHashCacheStore::publish(CacheEntry *pEntry)
         (int)sizeof(CeHeader))
         return -1;
 
+    pEntry->setBuilding(0);
+    if (updateEntryExpire(pEntry) != 0)
+        return -1;
     int ret = renameDiskEntry(pEntry, achTmp, sizeof(achTmp), ".tmp", NULL,
                               DHCS_SOURCE_MATCH | DHCS_DEST_CHECK);
     if (ret)
@@ -612,18 +749,49 @@ int DirHashCacheStore::publish(CacheEntry *pEntry)
     achTmp[len - 3] = 'S';
     achTmp[len - 2] = 0;
     unlink(achTmp);
-
-    CacheStore::iterator iter = find(pEntry->getHashKey().getKey());
-    if (iter != end())
-        dispose(iter, 0);
-
-    updateEntryState((DirHashCacheEntry *)pEntry);
-    insert((char *)pEntry->getHashKey().getKey(), pEntry);
-    getManager()->incStats(pEntry->isPrivate(), offsetof(cachestats_t,
-                           created));
-
-    return 0;
+    achTmp[len - 4] = 0;
+    if (pEntry->isDirty())
+    {
+        g_api->log(NULL, LSI_LOG_DEBUG, 
+                   "[CACHE] [%s] is marked dirty, do not add to hash.", achTmp);
+        return 0;
+    }
+    
+    return updateHashEntry(pEntry);
 }
 
 
+void DirHashCacheStore::removeEntryByHash(const unsigned char *pKey, int isPrivate)
+{
+    char achBuf[4096];
+    char *pathEnd; 
+    pathEnd = &achBuf[0] + buildCacheLocation(achBuf, 4096, pKey, isPrivate);
 
+    g_api->log(NULL, LSI_LOG_DEBUG, "[CACHE] remove cache object [%s].\n", achBuf);
+    unlink(achBuf);
+    
+    pathEnd -= 2 * HASH_KEY_LEN + 1;
+    assert(*pathEnd == '/');
+    
+    *pathEnd = 0;
+    if (rmdir(achBuf) == 0)
+    {
+        pathEnd -= 2;
+        assert(*pathEnd == '/');
+        *pathEnd = 0;
+        rmdir(achBuf);
+    }
+}
+
+
+void DirHashCacheStore::removeDeadEntry(CacheEntry *pEntry, 
+                                        const CacheHash &hash,
+                                        char *achBuf)
+{
+    getManager()->removeTracking((const char *)hash.getKey(), 
+                                    HASH_KEY_LEN, pEntry->isPrivate());
+    if (!achBuf[0])
+        buildCacheLocation(achBuf, 4096, hash.getKey(), pEntry->isPrivate());
+    delete pEntry;
+    unlink(achBuf);
+}
